@@ -947,7 +947,8 @@ class Askdata(SignUp):
                 self._token = r1.json()['access_token']
                 self.r1 = r1
 
-            authentication_url_userid = self.base_url_security + '/me'
+            print(self._token)
+            authentication_url_userid = self.base_url + '/me'
             self._headers = {
                 "Content-Type": "application/json",
                 "Authorization": "Bearer" + " " + self._token
@@ -1121,7 +1122,9 @@ class Askdata(SignUp):
         response = s.get(url=url, headers=headers)
         response.raise_for_status()
         file = open(datasetId+".parquet", 'wb').write(response.content)
-        return pd.read_parquet(datasetId+".parquet")
+        df = pd.read_parquet(datasetId + ".parquet")
+        os.remove(datasetId+".parquet")
+        return df
 
     def get_dataset_id(self, dataset_slug, workspace):
         url = self.base_url + '/smartbot/agents/agentslug/' + workspace + '/datasetslug/' + dataset_slug
