@@ -170,7 +170,7 @@ def data2nl(df, base_sentence=None, request=None, table_description=False):
         return df_response
 
 
-def query2sql(smartquery, driver):
+def query2sql(smartquery, driver, model_version=None):
     # Google Pod
     headers = {
         "Content-Type": "application/json"
@@ -186,20 +186,26 @@ def query2sql(smartquery, driver):
     stringed_smartquery = jsons.dumps(smartquery, strip_nulls=True)
     smartquery = json.loads(stringed_smartquery)
 
-    data = {
+    json_data = {
         "smartquery": smartquery,
         "driver": driver
     }
 
-    r = s.post(url=url, headers=headers, json=data)
+    # Params check
+    params = {}
+
+    if model_version is not None:
+        params["model_version"] = model_version
+
+    r = s.post(url=url, headers=headers, json=json_data, params=params)
     r.raise_for_status()
 
     try:
-        dict_response = r.json()
-        sql = dict_response['sql']
-        return sql
+        response = r.json()
+        return response["sql"]
     except Exception as e:
         logging.error(str(e))
+        return []
 
 
 def nl2query(nl, language="en-US"):
@@ -302,10 +308,12 @@ def complex_filter_calculator(smartquery, driver):
         logging.error(str(e))
 
 
-def smartner(nl, token, workspace, datasets, language="en-US"):
+def smartner(nl, datasets, token, use_cache=None, cache_mode=None, similarity_threshold=None, model_version=None,
+             env="dev", language="en", response_type="deanonymize"):
 
     headers = {
-        "Content-Type": "application/json"
+        "Content-Type": "application/json",
+        "authorization": "Bearer " + token
     }
 
     s = requests.Session()
@@ -313,23 +321,78 @@ def smartner(nl, token, workspace, datasets, language="en-US"):
     retries = Retry(total=5, backoff_factor=1, status_forcelist=[502, 503, 504])
     s.mount('https://', HTTPAdapter(max_retries=retries))
 
-    url = url_list['BASE_URL_SMARTNER_DEV'] + "/query"
+    if env == "dev":
+        url = url_list['BASE_URL_SMARTNER_DEV'] + "/query"
+    else:
+        url = url_list['BASE_URL_SMARTNER_PROD'] + "/query"
 
-    data = {
+    json_data = {
         "nl": nl,
-        "language": language,
-        "token": token,
-        "workspace": workspace,
+        "lang": language,
         "datasets": datasets
     }
 
-    r = s.post(url=url, headers=headers, json=data)
+    # Params check
+    params = {}
+
+    if use_cache in [True, False]:
+        params["use_cache"] = use_cache
+        if cache_mode in ["standard", "similarity", "only_cache"]:
+            params["cache_mode"] = cache_mode
+
+    if type(similarity_threshold) == int or type(similarity_threshold) == float:
+        params["similarity_threshold"] = similarity_threshold
+
+    if model_version is not None:
+        params["model_version"] = model_version
+
+    if response_type in ["anonymize", "nl2query", "deanonymize", "query2sql"]:
+        params["response_type"] = response_type
+
+    r = s.post(url=url, headers=headers, json=json_data, params=params)
     r.raise_for_status()
 
     try:
         response = r.json()
-        smartqueries_list = response["smartqueries"]
-        return smartqueries_list
+        return response["results"]
+    except Exception as e:
+        logging.error(str(e))
+        return []
+
+
+def smartner_automated_analysis(suggestions, token, env="dev", response_type="deanonymize"):
+
+    headers = {
+        "Content-Type": "application/json",
+        "authorization": "Bearer " + token
+    }
+
+    s = requests.Session()
+    s.keep_alive = False
+    retries = Retry(total=5, backoff_factor=1, status_forcelist=[502, 503, 504])
+    s.mount('https://', HTTPAdapter(max_retries=retries))
+
+    if env == "dev":
+        url = url_list['BASE_URL_SMARTNER_DEV'] + "/automated_analysis"
+    else:
+        url = url_list['BASE_URL_SMARTNER_PROD'] + "/automated_analysis"
+
+    json_data = {
+        "suggestions": suggestions
+    }
+
+    # Params check
+    params = {}
+
+    if response_type in ["anonymize", "nl2query", "deanonymize", "query2sql"]:
+        params["response_type"] = response_type
+
+    r = s.post(url=url, headers=headers, json=json_data, params=params)
+    r.raise_for_status()
+
+    try:
+        response = r.json()
+        return response["results"]
     except Exception as e:
         logging.error(str(e))
         return []
